task bcftools {

	Array[File] vcf
	String panel_id
	String docker
	String cluster_config
	String disk_size

	command <<<
		set -o pipefail
		set -e
    nt=$(nproc)

		mkdir -p /cromwell_root/tmp/bcftools

		for i in ${sep=" " vcf}
		do
      echo "Processing:" $i
			bcftools view $i -Oz -o /cromwell_root/tmp/bcftools/$(basename $i.gz) --threads $nt
			bcftools index /cromwell_root/tmp/bcftools/$(basename $i.gz) -f --threads $nt
		done

    echo "Start bcftools merge ..."
		bcftools merge -m all -f PASS,. --force-samples /cromwell_root/tmp/bcftools/*.vcf.gz --threads $nt | bcftools plugin fill-AN-AC | bcftools filter -i 'SUM(AC)>1' > ${panel_id}_pon.vcf
	>>>

	runtime {
		docker: docker
		cluster: cluster_config
		systemDisk: "cloud_ssd 40"
		dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
	}
	
	output {
		File panel_of_normal_vcf = "${panel_id}_pon.vcf"
	}
}